import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {MatTableDataSource} from "@angular/material/table";
import {ScriptAccount} from "../../../project/game-model/scriptAccounts/ScriptAccount";
import {Transition} from "../../../project/game-model/gamesystems/transitions/Transition";
import {ScriptAccountAction} from "../../../project/game-model/gamesystems/actions/ScriptAccountAction";
import {TemplateElement} from "../../../project/game-model/templates/TemplateElement";
import {
  SimpleTemplateTransition
} from "../../../project/game-model/templates/simpleGamesystem/SimpleTemplateTransition";
import {ScriptAccountCondition} from "../../../project/game-model/gamesystems/conditions/ScriptAccountCondition";

@Component({
  selector: 'app-scriptaccount-action-editor',
  templateUrl: './scriptaccount-action-editor.component.html',
  styleUrl: './scriptaccount-action-editor.component.scss'
})
export class ScriptaccountActionEditorComponent  implements OnInit{
  @Input() scriptAccounts: ScriptAccount[] = []
  @Input() enableEditing: boolean = false;
  @Input() actions: ScriptAccountAction[] = []
  @Output() onAddAction: EventEmitter<ScriptAccountAction> = new EventEmitter<ScriptAccountAction>();
  @Output() onRemoveAction: EventEmitter<ScriptAccountAction> = new EventEmitter<ScriptAccountAction>();

  dataSource: MatTableDataSource<ScriptAccountAction> = new MatTableDataSource();
  displayedColumns: string[] = ['scriptAccount', "valueChange", 'edit', 'delete'];

  editedAction: ScriptAccountAction | undefined
  addedAction: ScriptAccountAction | undefined

  ngOnInit() {
    this.dataSource.data = this.actions



    if(!this.enableEditing) {
      this.displayedColumns = this.displayedColumns.slice(0, -2);
    }
  }

  editAction(scriptAccountAction: ScriptAccountAction) {
    this.editedAction = scriptAccountAction;
  }

  createNewAction() {
    this.addedAction = new ScriptAccountAction(new ScriptAccount("", ""), 0);
    this.editedAction = this.addedAction;

    this.dataSource.data = this.dataSource.data.concat(this.addedAction);
  }

  finishEditing() {
    if(this.addedAction != undefined && this.addedAction.scriptAccount.componentName !== '') {
      this.onAddAction.emit(this.addedAction);
      this.addedAction = undefined;
    }
    this.editedAction = undefined;
  }


  deleteAction(deletedAction: ScriptAccountAction) {
    this.dataSource.data = this.dataSource.data.filter(action => action !== deletedAction);
    this.onRemoveAction.emit(deletedAction);
  }
}
