import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {MatTableDataSource} from "@angular/material/table";
import {ScriptAccountCondition} from "../../../project/game-model/gamesystems/conditions/ScriptAccountCondition";
import {ScriptAccount} from "../../../project/game-model/scriptAccounts/ScriptAccount";

@Component({
  selector: 'app-scriptaccount-condition-editor',
  templateUrl: './scriptaccount-condition-editor.component.html',
  styleUrl: './scriptaccount-condition-editor.component.scss'
})
export class ScriptaccountConditionEditorComponent implements OnInit{

  @Input() conditions: ScriptAccountCondition[] = []
  @Input() scriptAccounts: ScriptAccount[] = []
  @Input() enableEditiong: boolean = false
  @Output() onCreateCondition: EventEmitter<ScriptAccountCondition> = new EventEmitter<ScriptAccountCondition>();
  @Output() onDeleteCondition: EventEmitter<ScriptAccountCondition> = new EventEmitter<ScriptAccountCondition>();

  dataSource: MatTableDataSource<ScriptAccountCondition> = new MatTableDataSource();
  displayedColumns = ['scriptAccount', 'minValue', 'maxValue']

  editedCondition: ScriptAccountCondition | undefined
  addedCondition: ScriptAccountCondition | undefined

  ngOnInit() {
    this.dataSource.data = this.conditions.concat();

    if(this.enableEditiong) {
      this.displayedColumns.push( 'edit', 'delete')
    }
  }


  createCondition() {
    this.addedCondition = ScriptAccountCondition.constructScriptAccountCondition(new ScriptAccount("", ""), 0,0);
    this.editedCondition = this.addedCondition;
    this.dataSource.data = this.dataSource.data.concat(this.addedCondition!);
  }

  finishEditing() {
    if(this.addedCondition != undefined) {
      this.onCreateCondition.emit(this.addedCondition);
      this.addedCondition = undefined;
    }
    this.editedCondition = undefined;
  }

  edit(condition: ScriptAccountCondition) {
    this.editedCondition = condition;
  }

  deleteCondition(deletedCondition: ScriptAccountCondition) {
    this.onDeleteCondition.emit(deletedCondition);
    this.dataSource.data = this.dataSource.data.filter(condition => condition !== deletedCondition);
  }
}
