import {Component, Input, OnInit} from '@angular/core';
import {GamesystemCondition} from "../../../../project/game-model/interactions/condition/GamesystemCondition";
import {MatSnackBar} from "@angular/material/snack-bar";
import {MatTableDataSource} from "@angular/material/table";
import {CharacterDependency} from "../../../../project/game-model/interactions/CharacterDependency";
import {Gamesystem} from "../../../../project/game-model/gamesystems/Gamesystem";
import {AbstractInteraction} from "../../../../project/game-model/interactions/AbstractInteraction";

@Component({
  selector: 'app-gamesystem-condition-editor',
  templateUrl: './gamesystem-condition-editor.component.html',
  styleUrl: './gamesystem-condition-editor.component.scss'
})
export class GamesystemConditionEditorComponent implements OnInit{

  @Input() intgeraction: AbstractInteraction | undefined
  @Input() gamesystems: Gamesystem<any, any>[] = []
  editedCondition: GamesystemCondition | undefined
  addedCondition: GamesystemCondition | undefined

  datasource: MatTableDataSource<GamesystemCondition> = new MatTableDataSource<GamesystemCondition>();
  displayedColumns: string[] = ["characterDependency", "targetGamesystem", "requieredState", "edit", "delete"]

  constructor(private snackbar: MatSnackBar) {
  }

  ngOnInit() {
    this.datasource.data = this.intgeraction!.gamesystemConditions
  }

  editCondition(condition: GamesystemCondition) {
    this.editedCondition = condition;
  }

  finishEditingCondition() {
    if(this.editedCondition == undefined) {
      return;
    }

    if(this.editedCondition!.validate()) {
      if(this.editedCondition === this.addedCondition) {
        this.intgeraction!.addConditon(this.addedCondition);
        this.addedCondition = undefined
      }
      this.editedCondition = undefined;
    } else {
      this.snackbar.open("Invalid Condition", "", {duration: 2000});
    }
  }

  deleteCondition(deletedCondition: GamesystemCondition) {
    this.intgeraction!.removeCondition(deletedCondition);
    this.datasource.data = this.datasource.data.filter(condition => condition !== deletedCondition);
  }

  addCondition() {
    const condition = new GamesystemCondition(CharacterDependency.NONE, undefined, undefined);
    const displayedConditions = this.datasource.data;
    displayedConditions.push(condition);


    this.editedCondition = condition;
    this.addedCondition = condition;

    this.datasource.data = displayedConditions;
  }

  protected readonly CharacterDependency = CharacterDependency;
}
