import {Component, Input, OnInit} from '@angular/core';
import {AbstractInteraction} from "../../../../project/game-model/interactions/AbstractInteraction";
import {GameModel} from "../../../../project/game-model/GameModel";
import {MatTable, MatTableDataSource} from "@angular/material/table";
import {InventoryCondition} from "../../../../project/game-model/interactions/condition/InventoryCondition";
import {InventoryItemCondition} from "../../../../project/game-model/interactions/condition/InventoryItemCondition";
import {CharacterDependency} from "../../../../project/game-model/interactions/CharacterDependency";
import {
  InventoryItemgroupCondition
} from "../../../../project/game-model/interactions/condition/InventoryItemgroupCondition";
import {Item} from "../../../../project/game-model/inventory/Item";

@Component({
  selector: 'app-item-condition-editor',
  templateUrl: './item-condition-editor.component.html',
  styleUrl: './item-condition-editor.component.scss'
})
export class ItemConditionEditorComponent implements OnInit{

  @Input() interaction: AbstractInteraction | undefined
  @Input() gameModel: GameModel | undefined
  @Input() group: boolean = false;

  conditionDataSource: MatTableDataSource<InventoryCondition> = new MatTableDataSource();
  displayedColumns: string[] = ["item", "min", "max", "edit", "delete"];
  editedCondition: InventoryCondition | undefined
  addedCondition: InventoryCondition | undefined

  ngOnInit() {
    this.conditionDataSource.data = this.interaction!.inventoryConditions;
  }

  addCondition() {
     if(this.group) {
       this.addedCondition = new InventoryItemgroupCondition(CharacterDependency.NONE, 0, 0, undefined);
     } else {
       this.addedCondition = new InventoryItemCondition(CharacterDependency.NONE, 0, 0, undefined);
     }

    this.editedCondition = this.addedCondition;

    const displayedColumns = this.conditionDataSource.data;
    displayedColumns.push(this.addedCondition);
    this.conditionDataSource.data = displayedColumns;
  }

  editCondition(condition: InventoryCondition) {
    this.editedCondition = condition;
  }

  finishEditing() {
    if(this.editedCondition == undefined) {
      return;
    }

    if(this.editedCondition.validate()) {
      if(this.addedCondition != undefined) {
        this.interaction!.addConditon(this.addedCondition);
        this.addedCondition = undefined;
      }
      this.editedCondition = undefined;
    }
  }

  deleteCondition(deletedCondition: InventoryCondition) {
    this.interaction!.removeCondition(deletedCondition);
    this.conditionDataSource.data = this.conditionDataSource.data.filter(condition => condition !== deletedCondition);
  }

  conditionAsItemCondition(condition: InventoryCondition) {
    if(condition instanceof InventoryItemCondition) {
      return condition;
    } else {
      return undefined;
    }
  }

  conditionAsItemgroupCondition(condition: InventoryCondition) {
    if(condition instanceof InventoryItemgroupCondition) {
      return condition;
    } else {
      return undefined;
    }
  }

  onSelectedItemChange(condition: InventoryCondition, item: Item) {
    (condition as InventoryItemCondition).item = item;
    console.log(condition)
  }
}
